@@ -13,6 +13,12 @@ import org.gnu.glib.Type;
  *
  */
 public class CanvasPixbuf extends CanvasItem {
+
+	public CanvasPixbuf(CanvasGroup group) {
+		super(group, gnome_canvas_pixbuf_get_type());
+	}
+
+	
 	/**
 	 * Constructs an instance of CanvasPixbuf from a native widget resource.
 	 * @param handle The handle to the native widget.
@@ -21,9 +27,6 @@ public class CanvasPixbuf extends CanvasItem {
 		super(handle);
 	}
 
-	protected void noopInit() {
-	}
-
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
